@@ -43,6 +43,8 @@ def make_trainval_config(
             t.RandomSPNoise(p=data_cfg.RandomSPNoise) if data_cfg.RandomSPNoise else None,
             *val_transform,
         ])))
+    for k,v in cfg.items():
+        setattr(Config,k,v)
     return Config
 
 
@@ -179,7 +181,7 @@ def capacitor_app_demo(train_dir='',val_dir=''):
         MODEL_TYPE='resnet18',
         GEN_CLASSES_FILE=True,
         USE_tqdm_TRAIN=True,
-        USE_PRETRAINED=True,
+        USE_PRETRAINED=False,
         BATCH_SIZE=64,
         MAX_EPOCHS=200,
         BALANCE_CLASSES=True,
@@ -187,8 +189,9 @@ def capacitor_app_demo(train_dir='',val_dir=''):
         VAL_INTERVAL=1,
         WEIGHTS_SAVE_INTERVAL=1,
         WEIGHTS_INIT=None,
-        INPUT_W=224,
-        INPUT_H=224,
+        INPUT_W=360,
+        INPUT_H=270,
+        LOG_INFO=False,
         VISUALIZE_RESULT_DIR='data/visualize',
     )
     return make_simple_training_app(train_dir=train_dir,val_dir=val_dir,default_base_config=default_base_config,default_data_config=default_data_config)
